@@ -2,6 +2,7 @@ import os
 import sys
 import click
 from kamcli.cli import pass_context
+from kamcli.cli import COMMAND_ALIASES
 
 @click.group('config', help='Manage the config file')
 @pass_context
@@ -35,8 +36,16 @@ def config_show(ctx, sections):
 @cli.command('paths', short_help='Show the paths of configuration files')
 @pass_context
 def config_paths(ctx):
-    """Show the patsh of configuration files for kamcli"""
+    """Show the paths of configuration files for kamcli"""
     print()
     print(ctx.gconfig_paths)
     print()
 
+
+@cli.command('cmdaliases', short_help='Show the command aliases')
+@pass_context
+def config_cmdaliases(ctx):
+    """Show the command aliases"""
+    print()
+    print(COMMAND_ALIASES)
+    print()
\ No newline at end of file
