@@ -47,3 +47,38 @@ def srv_rpclist(ctx):
     """
     command_ctl(ctx, 'system.listMethods')
 
+##
+#
+#
+@cli.command('info', short_help='Show server info')
+@pass_context
+def srv_info(ctx):
+    """Show server info
+
+    \b
+    """
+    command_ctl(ctx, 'core.info')
+
+##
+#
+#
+@cli.command('modules', short_help='Show server loaded modules')
+@pass_context
+def srv_info(ctx):
+    """Show server loaded modules
+
+    \b
+    """
+    command_ctl(ctx, 'core.modules')
+
+##
+#
+#
+@cli.command('version', short_help='Show server version')
+@pass_context
+def srv_info(ctx):
+    """Show server version
+
+    \b
+    """
+    command_ctl(ctx, 'core.version')
\ No newline at end of file
